"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _optionsDefaults = _interopRequireDefault(require("./schemas/optionsDefaults"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var isNamespacedStyleName = function isNamespacedStyleName(styleName) {
  return styleName.indexOf('.') !== -1;
};

var handleError = function handleError(message, handleMissingStyleName) {
  if (handleMissingStyleName === 'throw') {
    throw new Error(message);
  } else if (handleMissingStyleName === 'warn') {
    // eslint-disable-next-line no-console
    console.warn(message);
  }

  return null;
};

var handleErrorPreserve = function handleErrorPreserve(msg, handleMissingStyleName, styleName, removeUnknownClassName) {
  var ret = handleError(msg, handleMissingStyleName);

  if (!removeUnknownClassName) {
    // eslint-disable-next-line no-console
    console.log('preserve className', styleName);
    ret = styleName;
  }

  return ret;
};

var getClassNameForNamespacedStyleName = function getClassNameForNamespacedStyleName(styleName, styleModuleImportMap, handleMissingStyleNameOption, removeUnknownClassName) {
  // Note:
  // Do not use the desctructing syntax with Babel.
  // Desctructing adds _slicedToArray helper.
  var styleNameParts = styleName.split('.');
  var importName = styleNameParts[0];
  var moduleName = styleNameParts[1];
  var handleMissingStyleName = handleMissingStyleNameOption || _optionsDefaults["default"].handleMissingStyleName;

  if (!moduleName) {
    return handleErrorPreserve('Invalid style name: ' + styleName, handleMissingStyleName, styleName, removeUnknownClassName);
  }

  if (!styleModuleImportMap[importName]) {
    return handleErrorPreserve('CSS module import does not exist: ' + importName, handleMissingStyleName, styleName, removeUnknownClassName);
  }

  if (!styleModuleImportMap[importName][moduleName]) {
    return handleErrorPreserve('CSS module does not exist: ' + moduleName, handleMissingStyleName, styleName, removeUnknownClassName);
  }

  return styleModuleImportMap[importName][moduleName];
};

var getClassNameFromMultipleImports = function getClassNameFromMultipleImports(styleName, styleModuleImportMap, handleMissingStyleNameOption, removeUnknownClassName) {
  var handleMissingStyleName = handleMissingStyleNameOption || _optionsDefaults["default"].handleMissingStyleName;
  var importKeysWithMatches = Object.keys(styleModuleImportMap).map(function (importKey) {
    return styleModuleImportMap[importKey][styleName] && importKey;
  }).filter(function (importKey) {
    return importKey;
  });

  if (importKeysWithMatches.length > 1) {
    throw new Error('Cannot resolve styleName "' + styleName + '" because it is present in multiple imports:' + '\n\n\t' + importKeysWithMatches.join('\n\t') + '\n\nYou can resolve this by using a named import, e.g:' + '\n\n\timport foo from "' + importKeysWithMatches[0] + '";' + '\n\t<div styleName="foo.' + styleName + '" />' + '\n\n');
  }

  if (importKeysWithMatches.length === 0) {
    return handleErrorPreserve('Could not resolve the styleName \'' + styleName + '\'.', handleMissingStyleName, styleName, removeUnknownClassName);
  }

  return styleModuleImportMap[importKeysWithMatches[0]][styleName];
};

var _default = function _default(styleNameValue, styleModuleImportMap, options) {
  var styleModuleImportMapKeys = Object.keys(styleModuleImportMap);

  var _ref = options || {},
      _ref$handleMissingSty = _ref.handleMissingStyleName,
      handleMissingStyleName = _ref$handleMissingSty === void 0 ? _optionsDefaults["default"].handleMissingStyleName : _ref$handleMissingSty,
      _ref$autoResolveMulti = _ref.autoResolveMultipleImports,
      autoResolveMultipleImports = _ref$autoResolveMulti === void 0 ? _optionsDefaults["default"].autoResolveMultipleImports : _ref$autoResolveMulti,
      removeUnknownClassName = _ref.removeUnknownClassName;

  if (!styleNameValue) {
    return '';
  }

  return styleNameValue.split(' ').filter(function (styleName) {
    return styleName;
  }).map(function (styleName) {
    if (isNamespacedStyleName(styleName)) {
      return getClassNameForNamespacedStyleName(styleName, styleModuleImportMap, handleMissingStyleName, removeUnknownClassName);
    } // console.log('styleModuleImportMapKeys', styleModuleImportMapKeys)


    if (styleModuleImportMapKeys.length === 0) {
      var include = options.include,
          exclude = options.exclude;
      var errMsg = 'Cannot use styleName attribute for style name \'' + styleName + '\' without importing at least one stylesheet.';

      if (include || exclude) {
        return console.warn(errMsg);
      }

      throw new Error(errMsg);
    }

    if (styleModuleImportMapKeys.length > 1) {
      if (!autoResolveMultipleImports) {
        throw new Error('Cannot use anonymous style name \'' + styleName + '\' with more than one stylesheet import without setting \'autoResolveMultipleImports\' to true.');
      }

      return getClassNameFromMultipleImports(styleName, styleModuleImportMap, handleMissingStyleName, removeUnknownClassName);
    }

    var styleModuleMap = styleModuleImportMap[styleModuleImportMapKeys[0]];

    if (!styleModuleMap[styleName]) {
      return handleErrorPreserve('Could not resolve the styleName \'' + styleName + '\'.', handleMissingStyleName, styleName, removeUnknownClassName);
    }

    return styleModuleMap[styleName];
  }).filter(function (className) {
    // Remove any styles which could not be found (if handleMissingStyleName === 'ignore')
    return className;
  }).join(' ');
};

exports["default"] = _default;

//# sourceMappingURL=getClassName.js.map